
import { LucideAlignJustify } from "lucide-react"
import {
	NavigationMenu,
	NavigationMenuContent,
	NavigationMenuItem,
	NavigationMenuLink,
	NavigationMenuList,
	NavigationMenuTrigger,
} from "@/components/ui/navigation-menu"
import { Link } from "react-router";
import { useForm, type SubmitHandler } from "react-hook-form"
import { useRef, useState } from "react";
import { z } from "zod";
import { Label } from "./components/ui/label";
import { Input } from "./components/ui/input";
import { Button } from "./components/ui/button";
import { rootstr } from "./rooturl";


interface AdminAccount {
	name: string,
	password: string
}
const totp_generation = z.object({
	img: z.string(),
	key: z.string()
})

const NewAccount = () => {
	const { register, handleSubmit, getValues } = useForm<AdminAccount>()
	const onSubmit: SubmitHandler<AdminAccount> = (data) => {
		SetCreateState(true)
		if (totp.current.length == 0) {
			alert("Didn't fetch totp secret")
			return false
		}
		fetch(rootstr + "/api/admin/create", { credentials: "include", body: JSON.stringify({ "name": data.name, "password": data.password, "totp_secret": totp.current }), headers: { "Content-Type": "application/json" }, method: "POST" }).then(
			async e => {
				if ((e.status == 401 || e.status == 400) && await e.text() == "missing or malformed JWT") {
					window.location.href = "/admin/login"
				} else {
					alert(e.statusText)
				}
			}).finally(() => SetCreateState(false))

	}
	const [totp_img, setTOTPImg] = useState("")
	const totp = useRef("")
	const [create_state, SetCreateState] = useState(false)
	const generate_totp = () => {
		let data = getValues()
		if (data.name.length > 0) {
			fetch(rootstr + "/api/admin/new_totp?name=" + data.name, { credentials: "include" }).then(async e => {
				if (e.status == 200) {
					let x = totp_generation.parse(await e.json())
					setTOTPImg(x.img)
					totp.current = x.key
				} else
					if ((e.status == 401 || e.status == 400) && await e.text() == "missing or malformed JWT") {
						window.location.href = "/admin/login"
					}
					else {
						alert(e.statusText + " " + e.text())
					}
			})
		}
	}


	return (<div className="w-full h-dvh bg-stone-700 relative">
		<div className="absolute top-0 right-0 m-3">
			<NavigationMenu>
				<NavigationMenuList>
					<NavigationMenuItem>
						<NavigationMenuTrigger><LucideAlignJustify /> </NavigationMenuTrigger>
						<NavigationMenuContent>
							<NavigationMenuLink asChild>
								<Link to="/admin/panel">Panel</Link>
							</NavigationMenuLink>
							<NavigationMenuLink asChild>
								<Link to="/admin/new_account">New Account</Link>
							</NavigationMenuLink>
						</NavigationMenuContent>
					</NavigationMenuItem>
				</NavigationMenuList>
			</NavigationMenu>
		</div>
		<div className="h-full w-full flex flex-row px-10 pt-20 text-white">
			<form onSubmit={handleSubmit(onSubmit)}>
				<Label>Name</Label>
				<Input {...register("name")} />
				<Label>Password</Label>
				<Input {...register("password")} />
				<img src={"data:image/png;base64, " + totp_img} height={200} width={200} alt="TOTP image" />
				<Button type="button" onClick={generate_totp} autoFocus={false}>Load TOTP Image</Button>
				<Input type="submit" disabled={create_state} />
			</form>

		</div>
	</div>)
}
export default NewAccount;
